@@ -13,7 +13,7 @@
 # You should have received a copy of the GNU General Public License along 
 # with this program.  If not, see <http://www.gnu.org/licenses/>.
 ### END LICENSE
-import urllib
+import urllib.parse
 import random
 
 import logging
@@ -44,7 +44,7 @@ class WallhavenDownloader(Downloader.Downloader):
         else:
             # interpret location as keywords
             self.url = "https://alpha.wallhaven.cc/search?q=%s&categories=111&purity=100&sorting=favorites&order=desc" % \
-                       urllib.quote(self.location)
+                       urllib.parse.quote(self.location)
 
     def search(self, page=None):
         url = self.url
@@ -58,7 +58,8 @@ class WallhavenDownloader(Downloader.Downloader):
 
         result_count = None
         try:
-            result_count = int(soup.find('header', {'class': 'listing-header'}).find('h1').text.split()[0])
+            result_count = int(soup.find('header', {'class': 'listing-header'})
+                               .find('h1').text.split()[0].replace(',', ''))
         except:
             pass
 
@@ -120,7 +121,7 @@ class WallhavenDownloader(Downloader.Downloader):
             sfw_rating = {'sfw': 100, 'sketchy': 50, 'nsfw': 0}[purity]
             extra_metadata['sfwRating'] = sfw_rating
 
-            if self.parent.options.safe_mode and sfw_rating < 100:
+            if self.parent and self.parent.options.safe_mode and sfw_rating < 100:
                 logger.info(lambda: "Skipping non-safe download from Wallhaven. "
                                     "Is the source %s suitable for Safe mode?" % self.location)
                 return None
@@ -139,7 +140,7 @@ class WallhavenDownloader(Downloader.Downloader):
             s, count = self.search()
             if not count:
                 count = 300
-            pages = min(count, 300) / 24 + 1
+            pages = min(count, 300) // 24 + 1
             page = random.randint(1, pages)
             logger.info(lambda: '%s wallpapers in result, using page %s' % (count, page))
             s, count = self.search(page=page)
@@ -149,7 +150,7 @@ class WallhavenDownloader(Downloader.Downloader):
         thumbs = s.find_all('figure', {'class': 'thumb'})
         for thumb in thumbs:
             try:
-                p = map(int, thumb.find('span', {'class': 'wall-res'}).contents[0].split('x'))
+                p = list(map(int, thumb.find('span', {'class': 'wall-res'}).contents[0].split('x')))
                 width = p[0]
                 height = p[1]
                 if self.parent and not self.parent.size_ok(width, height):
